import { KatexOptions } from 'katex';
import { MarkedOptions } from 'marked';
import { HTMLElement } from 'nodom';
import { Options as RendererOpts, NbRenderer } from './renderer';
export { default as version } from './version';
export { NbRenderer };
export declare type Options = RendererOpts<HTMLElement> & {
    /**
     * The prefix to be used for all CSS class names except `lang-*`.
     * Default is `nb-`.
     */
    classPrefix?: string;
    /**
     * Options for the KaTeX math renderer. Default is
     * `{ displayMode: true, throwOnError: false }`. The provided options will
     * be merged with the default.
     */
    katexOpts?: KatexOptions;
    /**
     * Options for the marked Markdown renderer.
     */
    markedOpts?: MarkedOptions;
};
declare const _default: (opts?: Options) => {
    Notebook: (notebook: import("./nbformat").Notebook) => HTMLElement;
    Cell: (cell: import("./nbformat").Cell, notebook: import("./nbformat").Notebook) => HTMLElement;
    MarkdownCell: (cell: import("./nbformat").MarkdownCell, _notebook: import("./nbformat").Notebook) => HTMLElement;
    RawCell: (cell: import("./nbformat").RawCell, _notebook: import("./nbformat").Notebook) => HTMLElement;
    CodeCell: (cell: import("./nbformat").CodeCell, notebook: import("./nbformat").Notebook) => HTMLElement;
    Source: (cell: import("./nbformat").CodeCell, notebook: import("./nbformat").Notebook) => HTMLElement;
    Output: (output: import("./nbformat").Output, cell: import("./nbformat").CodeCell) => HTMLElement;
    DisplayData: (output: import("./nbformat").DisplayData) => HTMLElement;
    ExecuteResult: (output: import("./nbformat").ExecuteResult) => HTMLElement;
    Error: (error: import("./nbformat").Error) => HTMLElement;
    Stream: (stream: import("./nbformat").Stream) => HTMLElement;
} & ((notebook: import("./nbformat").Notebook) => HTMLElement);
/**
 * Builds a full-fledged Notebook renderer for server-side rendering with a
 * fake DOM implementation "nodom".
 *
 * It supports rendering of Markdown cells with math (using marked and KaTeX),
 * code highlighting (using highlight.js), rendering of ANSI escape sequences
 * (using Anser) and SageMath-style math outputs. All of them may be overridden
 * via *opts*.
 *
 * It returns a "callable object" that exposes one renderer function for each
 * of the Notebook's AST nodes. You can easily replace any of the functions to
 * modify behaviour of the renderer.
 */
export default _default;
//# sourceMappingURL=index.d.ts.map