"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const anser_1 = __importDefault(require("anser"));
const highlightjs_1 = __importDefault(require("highlightjs"));
const katex_1 = __importDefault(require("katex"));
const nodom_1 = require("nodom");
const elementCreator_1 = __importDefault(require("./elementCreator"));
const htmlRenderer_1 = __importDefault(require("./htmlRenderer"));
const markdownRenderer_1 = __importDefault(require("./markdownRenderer"));
const renderer_1 = __importDefault(require("./renderer"));
var version_1 = require("./version");
exports.version = version_1.default;
const defaultKatexOpts = {
    displayMode: true,
    throwOnError: false,
};
function ansiCodesRenderer(input) {
    return anser_1.default.ansiToHtml(anser_1.default.escapeForHtml(input));
}
function codeHighlighter(code, lang) {
    return highlightjs_1.default.getLanguage(lang)
        ? highlightjs_1.default.highlight(lang, code).value
        : code;
}
const src = (opts = {}) => {
    const katexOpts = { ...defaultKatexOpts, ...opts.katexOpts };
    const doc = new nodom_1.Document();
    const elementCreator = elementCreator_1.default(doc.createElement.bind(doc), opts.classPrefix);
    const markdownRenderer = markdownRenderer_1.default(opts.markedOpts, katexOpts);
    const mathRenderer = (tex) => katex_1.default.renderToString(tex, katexOpts);
    const dataRenderers = {
        'text/html': htmlRenderer_1.default({ elementCreator, mathRenderer }),
        ...opts.dataRenderers,
    };
    return renderer_1.default(elementCreator, {
        ansiCodesRenderer,
        codeHighlighter,
        dataRenderers,
        markdownRenderer,
        ...opts,
    });
};
/**
 * Builds a full-fledged Notebook renderer for server-side rendering with a
 * fake DOM implementation "nodom".
 *
 * It supports rendering of Markdown cells with math (using marked and KaTeX),
 * code highlighting (using highlight.js), rendering of ANSI escape sequences
 * (using Anser) and SageMath-style math outputs. All of them may be overridden
 * via *opts*.
 *
 * It returns a "callable object" that exposes one renderer function for each
 * of the Notebook's AST nodes. You can easily replace any of the functions to
 * modify behaviour of the renderer.
 */
exports.default = src;
//# sourceMappingURL=index.js.map